@@ -1,12 +1,16 @@
 import datetime
+import json
+import os
 import unittest
 import uuid
 
 import psycopg2
 
+from peewee import print_
 from playhouse.postgres_ext import *
 
 
+TEST_VERBOSITY = int(os.environ.get('PEEWEE_TEST_VERBOSITY') or 1)
 test_db = PostgresqlExtDatabase('peewee_test', user='postgres')
 test_ss_db = PostgresqlExtDatabase(
     'peewee_test',
@@ -25,6 +29,12 @@ class Testing(BaseModel):
     class Meta:
         order_by = ('name',)
 
+try:
+    class TestingJson(BaseModel):
+        data = JSONField()
+except:
+    TestingJson = None
+
 class TestingID(BaseModel):
     uniq = UUIDField()
 
@@ -44,7 +54,6 @@ class SSCursorModel(Model):
 class NormalModel(BaseModel):
     data = CharField()
 
-
 class PostgresExtTestCase(unittest.TestCase):
     def setUp(self):
         Testing.drop_table(True)
@@ -56,10 +65,6 @@ class PostgresExtTestCase(unittest.TestCase):
         self.t1 = None
         self.t2 = None
 
-    def create(self):
-        self.t1 = Testing.create(name='t1', data={'k1': 'v1', 'k2': 'v2'})
-        self.t2 = Testing.create(name='t2', data={'k2': 'v2', 'k3': 'v3'})
-
     def test_uuid(self):
         uuid_str = 'a0eebc99-9c0b-4ef8-bb6d-6bb9bd380a11'
         uuid_obj = uuid.UUID(uuid_str)
@@ -84,6 +89,10 @@ class PostgresExtTestCase(unittest.TestCase):
         tz = TZModel.get(TZModel.id == tz.id)
         self.assertFalse(tz.dt.tzinfo is None)
 
+    def create(self):
+        self.t1 = Testing.create(name='t1', data={'k1': 'v1', 'k2': 'v2'})
+        self.t2 = Testing.create(name='t2', data={'k2': 'v2', 'k3': 'v3'})
+
     def test_storage(self):
         self.create()
         self.assertEqual(Testing.get(name='t1').data, {'k1': 'v1', 'k2': 'v2'})
@@ -139,6 +148,15 @@ class PostgresExtTestCase(unittest.TestCase):
             ('t2', True),
         ])
 
+        sq = Testing.select(Testing.name, Testing.data['k1'].alias('k1'))
+        self.assertEqual([(x.name, x.k1) for x in sq], [
+            ('t1', 'v1'),
+            ('t2', None),
+        ])
+
+        sq = Testing.select(Testing.name).where(Testing.data['k1'] == 'v1')
+        self.assertEqual([x.name for x in sq], ['t1'])
+
     def test_filtering(self):
         self.create()
 
@@ -237,6 +255,35 @@ class PostgresExtTestCase(unittest.TestCase):
         self.assertEqual(am_db.tags, ['alpha', 'beta', 'gamma', 'delta'])
         self.assertEqual(am_db.ints, [[1, 2], [3, 4], [5, 6]])
 
+    def test_array_search(self):
+        def assertAM(where, *instances):
+            query = (ArrayModel
+                     .select()
+                     .where(where)
+                     .order_by(ArrayModel.id))
+            self.assertEqual([x.id for x in query], [x.id for x in instances])
+
+        am = self._create_am()
+        am2 = ArrayModel.create(tags=['alpha', 'beta'], ints=[[1, 1]])
+        am3 = ArrayModel.create(tags=['delta'], ints=[[3, 4]])
+
+        assertAM((Param('beta') == fn.Any(ArrayModel.tags)), am, am2)
+        assertAM((Param('delta') == fn.Any(ArrayModel.tags)), am, am3)
+        assertAM((Param('omega') == fn.Any(ArrayModel.tags)))
+
+        # Check the contains operator.
+        assertAM(SQL("tags @> ARRAY['beta']::varchar[]"), am, am2)
+
+        # Use the nicer API.
+        assertAM(ArrayModel.tags.contains('beta'), am, am2)
+        assertAM(ArrayModel.tags.contains('omega', 'delta'))
+        assertAM(ArrayModel.tags.contains('alpha', 'delta'), am)
+
+        # Check for any.
+        assertAM(ArrayModel.tags.contains_any('beta'), am, am2)
+        assertAM(ArrayModel.tags.contains_any('omega', 'delta'), am, am3)
+        assertAM(ArrayModel.tags.contains_any('alpha', 'delta'), am, am2, am3)
+
     def test_array_index_slice(self):
         self._create_am()
         res = (ArrayModel
@@ -371,3 +418,45 @@ class SSCursorTestCase(unittest.TestCase):
         # the table.
         test_ss_db.execute_sql('truncate table %s;' % tbl)
         test_ss_db.commit()
+
+if TestingJson is not None:
+    from psycopg2.extras import Json
+
+    class TestJsonField(unittest.TestCase):
+        def setUp(self):
+            TestingJson.drop_table(True)
+            TestingJson.create_table()
+
+        def test_json_field(self):
+            data = {'k1': ['a1', 'a2'], 'k2': {'k3': 'v3'}}
+            tj = TestingJson.create(data=data)
+            tj_db = TestingJson.get(tj.pk_expr())
+            self.assertEqual(tj_db.data, data)
+
+        def assertItems(self, where, *items):
+            query = TestingJson.select().where(where).order_by(TestingJson.id)
+            self.assertEqual(
+                [item.id for item in query],
+                [item.id for item in items])
+
+        def test_lookup(self):
+            t1 = TestingJson.create(data={'k1': 'v1', 'k2': {'k3': 'v3'}})
+            t2 = TestingJson.create(data={'k1': 'x1', 'k2': {'k3': 'x3'}})
+            t3 = TestingJson.create(data={'k1': 'v1', 'j2': {'j3': 'v3'}})
+            self.assertItems((TestingJson.data['k2']['k3'] == 'v3'), t1)
+            self.assertItems((TestingJson.data['k1'] == 'v1'), t1, t3)
+
+            # Valid key, no matching value.
+            self.assertItems((TestingJson.data['k2'] == 'v1'))
+
+            # Non-existent key.
+            self.assertItems((TestingJson.data['not-here'] == 'v1'))
+
+            # Non-existent nested key.
+            self.assertItems((TestingJson.data['not-here']['xxx'] == 'v1'))
+
+            self.assertItems((TestingJson.data['k2']['xxx'] == 'v1'))
+
+
+elif TEST_VERBOSITY > 0:
+    print_('Skipping postgres "Json" tests, unsupported version.')
